#
# spec file for package maven-remote-resources-plugin
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with tests
Name:           maven-remote-resources-plugin
Version:        1.7.0
Release:        150200.3.4.3
Summary:        Maven Remote Resources Plugin
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-remote-resources-plugin/
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{name}/%{version}/%{name}-%{version}-source-release.zip
Patch0:         0001-Port-to-Maven-3.patch
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  unzip
BuildRequires:  mvn(commons-io:commons-io)
BuildRequires:  mvn(org.apache.maven.plugin-tools:maven-plugin-annotations)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildRequires:  mvn(org.apache.maven.shared:maven-common-artifact-filters)
BuildRequires:  mvn(org.apache.maven.shared:maven-filtering)
BuildRequires:  mvn(org.apache.maven:maven-archiver)
BuildRequires:  mvn(org.apache.maven:maven-artifact)
BuildRequires:  mvn(org.apache.maven:maven-compat)
BuildRequires:  mvn(org.apache.maven:maven-core)
BuildRequires:  mvn(org.apache.maven:maven-model)
BuildRequires:  mvn(org.apache.maven:maven-plugin-api)
BuildRequires:  mvn(org.apache.maven:maven-settings)
BuildRequires:  mvn(org.apache.velocity:velocity)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.codehaus.plexus:plexus-interpolation)
BuildRequires:  mvn(org.codehaus.plexus:plexus-resources)
BuildRequires:  mvn(org.codehaus.plexus:plexus-utils)
BuildArch:      noarch
%if %{with tests}
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(org.apache.maven.plugin-testing:maven-plugin-testing-harness)
BuildRequires:  mvn(org.apache.maven.shared:maven-verifier)
BuildRequires:  mvn(org.apache.maven.wagon:wagon-provider-api)
BuildRequires:  mvn(org.apache.velocity:velocity)
%endif

%description
Process resources packaged in JARs that have been deployed to
a remote repository. The primary use case being satisfied is
the consistent inclusion of common resources in a large set of
projects. Maven projects at Apache use this plug-in to satisfy
licensing requirements at Apache where each project much include
license and notice files for each release.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q
%patch0 -p1

%build
%{mvn_build} \
%if %{without tests}
    -f \
%endif
    -- \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE

%changelog
* Wed May 11 2022 fstrba@suse.com
- Upgrade to version 1.7.0
  * Changes:
    + MRRESOURCES-114 - use reproducible
    project.build.outputTimestamp
    + MRRESOURCES-112 - Require Java 7
    + MRRESOURCES-111 - "Copying" message before instead of
    "Copied" after
    + MRRESOURCES-111 - added INFO on number of resources
    bundled/copied
    + MRRESOURCES-94 - Lazily provide projects* Velocity properties
    + MPOM-205 - use sha512 checksums instead of sha1
    + MNGSITE-341 - use https for sigs, hashes and KEYS
    + MRRESOURCES-109 - - Upgrade plexus-utils from 3.0.24 to 3.1.0
    + MRRESOURCES-108 - - Upgrade plexus-interpolation to 1.25
    + MRRESOURCES-107 - - Upgrade JUnit from 4.11 to 4.12
    + MRRESOURCES-103 - Upgrade parent to 32
    + INFRA-16467 - move components documentation out of CMS space
    + MNGSITE-328 - use sha1 checksum instead of md5
    + MRRESOURCES-100 - Upgrade maven-filtering to 3.1.1
    + MRRESOURCES-99 - Upgrade of plexus-interpolation to 1.24.
    + MRRESOURCES-97] Upgrade maven-shared-components parent to
    version 30
    + MPOM-95 - updated parent pom location
    + MNGSITE-243 - Fixed link to How to use Mirros for Repositories
    + MRRESOURCES-95 - Upgrade plexus-resources from 1.0-alpha-7 to
    1.0.1
    + MRRESOURCES-91 - Avoid overwrite of the destination file if
    the produced contents is the same
    + MRRESOURCES-90 - Using project.isExecutionRoot() instead of
    the old way.
    + MRRESOURCES-89 - Removed deprecated attributes
    + MRRESOURCES-88 - Added a note about .vm on the usage page
    + MRRESOURCES-87 - Upgrade JUnit from 3.8.1 to 4.11
    + MRRESOURCES-86 - Remove unused dependency maven-monitor
    + MRRESOURCES-84 - Print warning in case no encoding has been
    set.
    + MRRESOURCES-84 - Print warning in case no encoding has been
    set.
    + MRRESOURCES-82 - Upgrade to maven-plugins parent version 27
    + MRRESOURCES-80 - Upgrade to maven-parent version 26  - Fixed
    according checkstyle reported issues.
    + MRRESOURCES-79 - Removed dependency
    plexus-container-default:1.0-alpha-9-stable-1
    + MRRESOURCES-77 - Upgrade maven-filtering to 1.3
    + MRRESOURCES-78 - Upgrade maven-plugin-testing-harness to 1.3
    + MRRESOURCES-76 - Updated plexus-archiver
    + MNGSITE-152 - Added missing download.cgi and
    xdoc/download.xml.vm
    + MNGSITE-152 - Added appropriate links to download site and
    license location to fulfill the ASF requirements.
    + MRRESOURCES-70 - SVN settings: eol-style and keywords
- Added patch:
  * 0001-Port-to-Maven-3.patch
    + port tests to modern maven framework
- Add with tests option
* Tue Mar 22 2022 fstrba@suse.com
- Build with source and target levels 8
* Sun Nov 24 2019 fstrba@suse.com
- Specify maven.compiler.release to fix build with jdk9+ and newer
  maven-javadoc-plugin
* Tue Oct  1 2019 fstrba@suse.com
- Not needed any more the hint to require mvn(log4j:log4j)
* Mon Jun  3 2019 jengelh@inai.de
- Add missing Group: for javadoc subpackage.
* Fri May  3 2019 fstrba@suse.com
- Initial packaging of maven-remote-resources-plugin 1.5
